Lighthouse has a new layout. Prefer the old one? Return to the old layout, and switch back any time from the link at the top of each page.

This project is archived and is in readonly mode.

[PATCH] Removing "symbol to proc" usage from Active Record

#5379

Hi,

I've seen the commits from Aaron Patterson on removing those symbol to proc (.map(&:method)) from the code to speeding up Active Record for a bit. I though it's a good idea, and wish I could help.

So, I've attached the patch which changes all the 'symbol to proc' in active_record/lib to a block. Noted that I've tried to use the variable name which is closest to the context. If it's inappropriate, please let me know

Thank you.

Reported by Prem Sichanugrist (sikachu) · August 14th, 2010 @ 12:06 AM

State: committed
Milestone: 3.x
Assigned to: Aaron Patterson Aaron Patterson
Importance: Medium

Activity

  1. Aaron Patterson
    Aaron Patterson
    • State changed from new to committed

    Applied. AR tests are 10% faster on my machine with sqlite3. Thanks!

    August 14th, 2010 @ 12:26 AM